@@ -46,8 +46,9 @@ class TokenProxy(Token):
     """
     @property
     def pk(self):
-        return self.user.pk
+        return self.user_id
 
     class Meta:
-        proxy = True
+        proxy = 'rest_framework.authtoken' in settings.INSTALLED_APPS
+        abstract = 'rest_framework.authtoken' not in settings.INSTALLED_APPS
         verbose_name = "token"
