@@ -25,11 +25,21 @@ from django.utils.decorators import classonlymethod
 from django.views.decorators.csrf import csrf_exempt
 
 from rest_framework import generics, mixins, views
+from rest_framework.decorators import MethodMapper
 from rest_framework.reverse import reverse
 
 
 def _is_extra_action(attr):
-    return hasattr(attr, 'mapping')
+    return hasattr(attr, 'mapping') and isinstance(attr.mapping, MethodMapper)
+
+
+def _check_attr_name(func, name):
+    assert func.__name__ == name, (
+        'Expected function (`{func.__name__}`) to match its attribute name '
+        '(`{name}`). If using a decorator, ensure the inner function is '
+        'decorated with `functools.wraps`, or that `{func.__name__}.__name__` '
+        'is otherwise set to `{name}`.').format(func=func, name=name)
+    return func
 
 
 class ViewSetMixin:
@@ -92,6 +102,10 @@ class ViewSetMixin:
 
         def view(request, *args, **kwargs):
             self = cls(**initkwargs)
+
+            if 'get' in actions and 'head' not in actions:
+                actions['head'] = actions['get']
+
             # We also store the mapping of request methods to actions,
             # so that we can later set the action attribute.
             # eg. `self.action = 'list'` on an incoming GET request.
@@ -103,9 +117,6 @@ class ViewSetMixin:
                 handler = getattr(self, action)
                 setattr(self, method, handler)
 
-            if hasattr(self, 'get') and not hasattr(self, 'head'):
-                self.head = self.get
-
             self.request = request
             self.args = args
             self.kwargs = kwargs
@@ -148,6 +159,11 @@ class ViewSetMixin:
         Reverse the action for the given `url_name`.
         """
         url_name = '%s-%s' % (self.basename, url_name)
+        namespace = None
+        if self.request and self.request.resolver_match:
+            namespace = self.request.resolver_match.namespace
+        if namespace:
+            url_name = namespace + ':' + url_name
         kwargs.setdefault('request', self.request)
 
         return reverse(url_name, *args, **kwargs)
@@ -157,7 +173,9 @@ class ViewSetMixin:
         """
         Get the methods that are marked as an extra ViewSet `@action`.
         """
-        return [method for _, method in getmembers(cls, _is_extra_action)]
+        return [_check_attr_name(method, name)
+                for name, method
+                in getmembers(cls, _is_extra_action)]
 
     def get_extra_action_url_map(self):
         """
@@ -180,6 +198,10 @@ class ViewSetMixin:
         for action in actions:
             try:
                 url_name = '%s-%s' % (self.basename, action.url_name)
+                namespace = self.request.resolver_match.namespace
+                if namespace:
+                    url_name = '%s:%s' % (namespace, url_name)
+
                 url = reverse(url_name, self.args, self.kwargs, request=self.request)
                 view = self.__class__(**action.kwargs)
                 action_urls[view.get_view_name()] = url
